/*
 * Copyright (c) 2018 Jeffrey Walter <jeffreydwalter@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package arlo

const (
	DeviceTypeArloQ       = "arloq"
	DeviceTypeArloBridge  = "arlobridge"
	DeviceTypeBasestation = "basestation"
	DeviceTypeCamera      = "camera"
	DeviceTypeLights      = "lights"
	DeviceTypeSiren       = "siren"

	TransIdPrefix = "web"
	BaseUrl       = "https://arlo.netgear.com/hmsweb"

	// TODO: Implement all of the following urls. There are many here I don't have devices for. :/
	ActiveAutomationUri           = "/users/devices/automation/active"
	AllMediaUri                   = "/users/music/all"
	AnalyticFeedbackUri           = "/users/library/%s/feedback"
	AssignBetaPlanUri             = "/users/assign/smartfeatures"
	AssignDeviceToServicePlanUri  = "/users/devices/provision"
	AutomationDefinitionsUri      = "/users/automation/definitions?uniqueIds=all"
	AutomationModeUri             = "/users/locations/%uniqueId/modes"
	AutomationScheduleUri         = "/users/locations/%uniqueId/schedules"
	BuyUri                        = "http:/www.arlo.com/en-us/products/default.aspx?utm_source=app_desktop&p=all&cid=app"
	CameraOrderUri                = "/users/devices/v2/displayOrder"
	CancelPlanUri                 = "/users/payment/plans/%paymentId/cancel"
	CancelQuotationUri            = "/users/payment/quotations/%paymentId/cancel/v1"
	CapabilitiesUri               = "/resources/capabilities/en/en_%t|i1000.json?t=%s"
	ChangeMobileOffersUri         = "/users/payment/offers/dataplans/change/v5"
	ChangePlanUri                 = "/users/%paymentId/changeplan"
	CheckAccountUri               = "/checkAccountUsage"
	CheckEmailUri                 = "/checkEmailUsage"
	ClaimDeviceUri                = "/users/devices/claimDevice"
	CommunityUri                  = "http:/www.arlo.com/community?utm_source=app_desktop&locale=en"
	ConfirmUserIdUri              = "/users/resend/confirm/email"
	CountryCodesUri               = "/static/countrycodes"
	CreatePaymentAccountUri       = "/users/payment/accounts"
	CreatePlanUri                 = "/users/payment/plans/%paymentId"
	DeleteAccountUri              = "/users/closeAccount"
	DeviceFeaturesUri             = "/users/devices/updateFeatures/feature/%uniqueId"
	DeviceProvisioningUri         = "/users/devices/states"
	DeviceStatisticsUri           = "/users/devices/%uniqueId/data/statistics?t=%s"
	DeviceSupportUri              = "/devicesupport"
	DeviceSupportV2Uri            = "/devicesupport/v2"
	DeviceUri                     = "/users/devices/%deviceId"
	DeviceZoneUri                 = "/users/devices/%uniqueId/activityzones/%zoneId"
	DeviceZonesUri                = "/users/devices/%uniqueId/activityzones"
	DevicesUpdateFeaturesUri      = "/users/devices/updateFeatures/feature"
	DevicesUri                    = "/users/devices/?t=%s"
	DonateRecordUri               = "/users/library/%uniqueId/donate"
	EditAutomationModeUri         = "/users/locations/%uniqueId/modes/%mode/devices/%i"
	EditUri                       = "/users/media"
	EmergencyCallDetailsUri       = "/users/emergency/%emergencyId/call"
	EmergencyLocationSaveUri      = "/users/emergency/locations/%emergencyId"
	EmergencyLocationsUri         = "/users/emergency/locations"
	EventsUri                     = "/users/devices/%uniqueId/events?fromDate=%s&toDate=%s"
	FavoriteUri                   = "/users/library/favorite"
	FieldLengthsUri               = "/static/fieldLengths"
	FriendsDeleteUri              = "/users/friends/remove"
	FriendsUri                    = "/users/friends"
	FullFrameSnapshotUri          = "/users/devices/fullFrameSnapshot"
	GPLUri                        = "https:/vzs3-prod-common.s3.amazonaws.com/license/GPLv1.html"
	HtmlChangeOffersUri           = "/users/payment/offers/html/v5/change"
	HtmlOffersUri                 = "/users/payment/offers/html/v5"
	HtmlPrelimQuotationUri        = "/users/payment/offers/quotation/html/v5"
	HtmlQuotationUri              = "/users/payment/confirmation/%paymentId"
	LibFeedbackUri                = "/library/feedback"
	LibraryStateUri               = "/users/library/state/v1"
	LocateDevicesUri              = "/locateDevice?discoveryToken=%s"
	LocationByZipUri              = "/users/payment/postalcodelookup"
	LocationUri                   = "/users/locations"
	LoginUri                      = "/login"
	LoginV2Uri                    = "/login/v2"
	LogoutUri                     = "/logout"
	MetadataUri                   = "/users/library/metadata/v2"
	MigrateZonesUri               = "/users/devices/%uniqueId/activityzones/migrate"
	MobileOffersUri               = "/users/payment/offers/dataplans/v5"
	ModifyBillingUri              = "/users/payment/billing/%paymentId"
	NotifyResponsesPushServiceUri = "/client/subscribe?token=%s"
	NotifyUri                     = "/users/devices/notify/%s"
	OffersDetailsUri              = "/users/payment/offersdetail"
	OffersDvrChangeUri            = "/users/payment/offers/arloq/html/v5/change"
	OffersDvrUri                  = "/users/payment/offers/arloq/html/v5"
	OffersUri                     = "/users/payment/offers/v3"
	PaymentBillingUri             = "/users/payment/billing/%paymentId"
	PaymentRenewUri               = "/users/payment/autoRenew/%paymentId"
	PaymentTermsLinkUri           = "/paymentTermsAndConditions?t=%s"
	PlacemeterUri                 = ""
	PlaylistMetaUri               = "/users/devices/%uniqueId/playlist/metadata"
	PlaylistUri                   = "/users/devices/%s/playlist?fromDate=%s&toDate=%s"
	PolicyUri                     = "/policy/v1/?t=%s"
	PreferencesUri                = "/users/preferences"
	ProfileUri                    = "/users/profile"
	PttNotifyUri                  = "/users/devices/notify/%parentId"
	PttUri                        = "/users/devices/%s/pushtotalk"
	RMAValidationUri              = "/users/devices/%restrictedDevice/apvalidation"
	RecordingsUri                 = "/users/library"
	RecycleUri                    = "/users/library/recycle"
	RegisterUserUri               = "/register"
	RemoveDeviceUri               = "/users/devices/v2/removeDevice"
	RenameDeviceUri               = "/users/devices/v2/renameDevice"
	RenewPlanUri                  = "/users/payment/plans/%paymentId/renew"
	RenewQuotationUri             = "/users/payment/quotations/%?/renew"
	RequestPasswordResetUri       = "/requestPasswordReset"
	ResetCountUri                 = "/users/library/reset?uniqueId=%s"
	ResetPasswordUri              = "/resetPassword"
	RestartDeviceUri              = "/users/devices/restart"
	SSORegisterUri                = "/ssoregister"
	SecretQuestionsUri            = "/static/secretquestions"
	ServicePlanUri                = "/users/serviceLevel/v3"
	SessionUri                    = "/users/session"
	SetAutomationModeUri          = "/users/locations/%uniqueId/modes/%mode"
	ShareUri                      = "/users/library/share"
	SmartAlertsUri                = "/users/devices/%uniqueId/smartalerts"
	SmartConfigUri                = "/user/smarthome/config"
	StartRecordUri                = "/users/devices/startRecord"
	StartStreamUri                = "/users/devices/startStream"
	StatesCodesUri                = "/static/usstatescodes"
	StopRecordUri                 = "/users/devices/stopRecord"
	StopStreamUri                 = "/users/devices/stopStream"
	StorageQuotaUri               = "/users/quota"
	SupportUri                    = "http:/www.arlo.com/support?utm_source=app_desktop&cc=en"
	TakeSnapshotUri               = "/users/devices/takeSnapshot"
	TempUnitUri                   = "/users/devices/%uniqueId/tempUnit"
	TermsLinkUri                  = "/termsAndConditionsLink?t=%s"
	TermsUri                      = "/termsAndConditions/?t=%s"
	TimeZonesUri                  = "/static/timezones"
	UnsubscribeUri                = "/client/unsubscribe"
	UpdateNameUri                 = "/user"
	UpdatePasswordUri             = "/users/changePassword"
	UpdateUserIdUri               = "/users/changeEmail"
	UserFrameSnapshotUri          = "/users/devices/userSnapshot"
	UsersEmailsUri                = "/users/emails"
	ValidateCouponUri             = "/users/payment/coupondetails"
	ValidateResetUri              = "/validatePasswordReset/%?"
	WakeupUri                     = "/users/devices/wakeup/%deviceId?t=%s"
)
